@@ -23,12 +23,13 @@
 #include "ipv4delegate.h"
 
 #include <QDialog>
+#include <QDialogButtonBox>
 #include <QStandardItemModel>
 #include <QItemSelection>
 #include <QNetworkAddressEntry>
 
 #include <KEditListWidget>
-#include <KDialog>
+#include <KLocalizedString>
 
 quint32 suggestNetmask(quint32 ip)
 {
@@ -81,7 +82,7 @@ IPv4Widget::IPv4Widget(const NetworkManager::Setting::Ptr &setting, QWidget* par
     m_ui->setupUi(this);
 
     m_ui->tableViewAddresses->setModel(&d->model);
-    m_ui->tableViewAddresses->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
+    m_ui->tableViewAddresses->horizontalHeader()->setResizeMode(QHeaderView::ResizeToContents);
     m_ui->tableViewAddresses->horizontalHeader()->setStretchLastSection(true);
 
     IpV4Delegate *ipDelegate = new IpV4Delegate(this);
@@ -410,14 +411,18 @@ void IPv4Widget::slotRoutesDialog()
 
 void IPv4Widget::slotDnsServers()
 {
-    QPointer<KDialog> dlg = new KDialog(this);
-    dlg->setCaption(i18n("Edit DNS servers"));
-    dlg->setButtons(KDialog::Ok | KDialog::Cancel);
-    KEditListWidget * listWidget = new KEditListWidget(dlg);
-    dlg->setMainWidget(listWidget);
+    QPointer<QDialog> dialog = new QDialog(this);
+    dialog->setWindowTitle(i18n("Edit DNS servers"));
+    dialog->setLayout(new QVBoxLayout);
+    QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel, dialog);
+    connect(buttons, SIGNAL(accepted()), dialog, SLOT(accept()));
+    connect(buttons, SIGNAL(rejected()), dialog, SLOT(reject()));
+    KEditListWidget * listWidget = new KEditListWidget(dialog);
     listWidget->setItems(m_ui->dns->text().split(',').replaceInStrings(" ", ""));
+    dialog->layout()->addWidget(listWidget);
+    dialog->layout()->addWidget(buttons);
 
-    if (dlg->exec() == KDialog::Accepted) {
+    if (dialog->exec() == QDialog::Accepted) {
         QString text = listWidget->items().join(",");
         if (text.endsWith(',')) {
             text.chop(1);
@@ -425,21 +430,25 @@ void IPv4Widget::slotDnsServers()
         m_ui->dns->setText(text);
     }
 
-    if (dlg) {
-        dlg->deleteLater();
+    if (dialog) {
+        dialog->deleteLater();
     }
 }
 
 void IPv4Widget::slotDnsDomains()
 {
-    QPointer<KDialog> dlg = new KDialog(this);
-    dlg->setCaption(i18n("Edit DNS search domains"));
-    dlg->setButtons(KDialog::Ok | KDialog::Cancel);
-    KEditListWidget * listWidget = new KEditListWidget(dlg);
-    dlg->setMainWidget(listWidget);
+    QPointer<QDialog> dialog = new QDialog(this);
+    dialog->setWindowTitle(i18n("Edit DNS search domains"));
+    dialog->setLayout(new QVBoxLayout);
+    QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel, dialog);
+    connect(buttons, SIGNAL(accepted()), dialog, SLOT(accept()));
+    connect(buttons, SIGNAL(rejected()), dialog, SLOT(reject()));
+    KEditListWidget * listWidget = new KEditListWidget(dialog);
     listWidget->setItems(m_ui->dnsSearch->text().split(',').replaceInStrings(" ", ""));
+    dialog->layout()->addWidget(listWidget);
+    dialog->layout()->addWidget(buttons);
 
-    if (dlg->exec() == KDialog::Accepted) {
+    if (dialog->exec() == QDialog::Accepted) {
         QString text = listWidget->items().join(",");
         if (text.endsWith(',')) {
             text.chop(1);
@@ -447,8 +456,8 @@ void IPv4Widget::slotDnsDomains()
         m_ui->dnsSearch->setText(text);
     }
 
-    if (dlg) {
-        dlg->deleteLater();
+    if (dialog) {
+        dialog->deleteLater();
     }
 }
 
